@@ -548,9 +548,9 @@ func TestSearchForUserGroupMembershipMapping(t *testing.T) {
 			GroupCommonName: "groupName",
 		},
 		GroupMapping: internal.GroupMapping{
-			Admin:      "administrator",
-			SuperAdmin: "super-administrator",
-			ReadOnly:   "read-only",
+			Admin:      []string{"administrator", "company-admins,bar"},
+			SuperAdmin: []string{"super-administrator", "company-super-admins"},
+			ReadOnly:   []string{"read-only", "company-read-only"},
 		},
 	}
 	controller := internal.NewLDAPController(settings, mock)
@@ -674,4 +674,109 @@ func TestSearchForUserGroupMembershipMapping(t *testing.T) {
 		require.Contains(t, groups, authenticationcallouts.UserGroupIDSuperAdmin)
 		require.Contains(t, groups, authenticationcallouts.UserGroupIDAdmin)
 	})
+
+	t.Run("multiple groups - admin", func(t *testing.T) {
+		mock.returnSearchValue = &ldap.SearchResult{
+			Entries: []*ldap.Entry{
+				{
+					Attributes: []*ldap.EntryAttribute{
+						{
+							Name:   "groupName",
+							Values: []string{"company-admins,bar"},
+						},
+					},
+				},
+			},
+		}
+
+		// Act
+		groups, isAllowed, err := controller.SearchForUserGroupMembership("foo")
+
+		// Assert
+		require.NoError(t, err)
+		require.False(t, isAllowed)
+		require.Len(t, groups, 1)
+		require.Contains(t, groups, authenticationcallouts.UserGroupIDAdmin)
+	})
+
+	t.Run("multiple groups - super-admin", func(t *testing.T) {
+		mock.returnSearchValue = &ldap.SearchResult{
+			Entries: []*ldap.Entry{
+				{
+					Attributes: []*ldap.EntryAttribute{
+						{
+							Name:   "groupName",
+							Values: []string{"company-super-admins"},
+						},
+					},
+				},
+			},
+		}
+
+		// Act
+		groups, isAllowed, err := controller.SearchForUserGroupMembership("foo")
+
+		// Assert
+		require.NoError(t, err)
+		require.False(t, isAllowed)
+		require.Len(t, groups, 1)
+		require.Contains(t, groups, authenticationcallouts.UserGroupIDSuperAdmin)
+	})
+
+	t.Run("multiple groups - read-only", func(t *testing.T) {
+		mock.returnSearchValue = &ldap.SearchResult{
+			Entries: []*ldap.Entry{
+				{
+					Attributes: []*ldap.EntryAttribute{
+						{
+							Name:   "groupName",
+							Values: []string{"company-read-only"},
+						},
+					},
+				},
+			},
+		}
+
+		// Act
+		groups, isAllowed, err := controller.SearchForUserGroupMembership("foo")
+
+		// Assert
+		require.NoError(t, err)
+		require.False(t, isAllowed)
+		require.Len(t, groups, 1)
+		require.Contains(t, groups, authenticationcallouts.UserGroupIDReadOnly)
+	})
+
+	t.Run("multiple groups - admin and super-admin", func(t *testing.T) {
+		mock.returnSearchValue = &ldap.SearchResult{
+			Entries: []*ldap.Entry{
+				{
+					Attributes: []*ldap.EntryAttribute{
+						{
+							Name:   "groupName",
+							Values: []string{"company-super-admins"},
+						},
+					},
+				},
+				{
+					Attributes: []*ldap.EntryAttribute{
+						{
+							Name:   "groupName",
+							Values: []string{"company-admins,bar"},
+						},
+					},
+				},
+			},
+		}
+
+		// Act
+		groups, isAllowed, err := controller.SearchForUserGroupMembership("foo")
+
+		// Assert
+		require.NoError(t, err)
+		require.False(t, isAllowed)
+		require.Len(t, groups, 2)
+		require.Contains(t, groups, authenticationcallouts.UserGroupIDSuperAdmin)
+		require.Contains(t, groups, authenticationcallouts.UserGroupIDAdmin)
+	})
 }
